@@ -2,29 +2,28 @@ import pygame
 import util
 from const import *
 from pygame.locals import *
-import widget, label
 
 from cellulose.restrictions import StringRestriction
 from cellulose import *
 
 
-class _button(widget.Widget):
+class _button(util.widgets.Widget):
 
     _label = util.ReplaceableCellDescriptor()
 
     def __init__(self, **params):
         self._label = None
-        widget.Widget.__init__(self, **params)
+        super(_button,self).__init__(**params)
 
 
     def set_label(self, v):
         if hasattr(v, "value"):
-            l = label.Label(v.value, parent=self)
+            l = util.widgets.Label(v.value, parent=self)
             l._cells["value"] = ComputedCell(lambda:str(v.value))
         if type(v) == int:
             v = str(v)
         if type(v) == str:
-            l = label.Label(v, parent=self)
+            l = util.widgets.Label(v, parent=self)
         self.send(CHANGE)
         self._label = l
         self._label._cells["hovering"] = self._cells["hovering"]
@@ -33,13 +32,17 @@ class _button(widget.Widget):
     label = property(lambda self: self._label, set_label)
 
     def width(self):
+        if not self.label:
+            return util.widgets.Widget.width.function(self)
         w = self.label.width + self.style_option["padding-left"]+self.style_option["padding-right"]
-        return widget.Widget.width.function(self, w)
+        return util.widgets.Widget.width.function(self, w)
     width = ComputedCellDescriptor(width)
 
     def height(self):
+        if not self.label:
+            return util.widgets.Widget.height.function(self)
         h = self.label.height + self.style_option["padding-top"]+self.style_option["padding-bottom"]
-        return widget.Widget.height.function(self, h)
+        return util.widgets.Widget.height.function(self,h)
     height = ComputedCellDescriptor(height)
 
 
@@ -64,9 +67,9 @@ class Button(_button):
     _value = util.ReplaceableCellDescriptor()
 
     def __init__(self, value=" ", **params):
-        _button.__init__(self, **params)
+        super(Button, self).__init__(**params)
         self._value = None
-        self.set_value(value)
+        self.value = value
 
     def set_value(self, v):
         self._value = v
@@ -78,43 +81,52 @@ class Button(_button):
 
 class Switch(_button):
     """
-    Switch([value, [on_label, [off_label]]]) -> Switch widget
-    ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
-    This is very similar to a button except the value will always be ether
-    True or False
+    Switch([value, [labels, [options]]]) -> Switch widget
+    ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+    This is very similar to a button. When clicked, it will cycle through it's
+    list of options. The label displayed will be the the item in the labels list
+    at the same index as the current option (value) in the options list. The
+    labels and options need to be exactly the same size.
 
     Arguments
     ---------
     value
-        You can set it to True or False (default).
-
-    on_label
-        The text displayed when the switch is on.
-
-    off_label
-        The text displayed when the switch is off.
+        Must be an item in the options list.
+    labels
+        A list of strings that will be used as labels.
+    options
+        A list of items that are cycled through to determin this widgets value.
     """
 
     _value = util.ReplaceableCellDescriptor()
     on_label = util.ReplaceableCellDescriptor()
     off_label = util.ReplaceableCellDescriptor()
 
-    def __init__(self, value=False, on_label="on", off_label="off", **params):
-        _button.__init__(self, **params)
+    def __init__(self, value=False, labels=("Off", "On"), options=(False,True),
+                **params):
+        super(Switch, self).__init__(**params)
         self._value = value
-        self.on_label = on_label
-        self.off_label = off_label
+        self.labels = list(labels)
+        self.options = list(options)
+        if len(self.labels) != len(self.options):
+            raise ValueError("The number of labels has to equal the number of options!")
         self.set_value(value)
 
 
     def set_value(self, v):
         self._value = v
-        if v == True:
-            self.label = self.on_label
-        else:
-            self.label = self.off_label
+        if v not in self.options:
+            error = """Could not find value in options.
+"""
+            error = error+"Value:"+str(v)+"  Options:"+str(self.options)
+            raise ValueError(error)
+        self.label = self.labels[self.options.index(v)]
     value = property(lambda self: self._value, set_value)
 
     def click(self):
-        self.value = not self.value
-        self.send(CHANGE)
\ No newline at end of file
+        i = self.options.index(self.value)
+        if i == len(self.options)-1:
+            i = 0
+        else:
+            i += 1
+        self.value = self.options[i]
\ No newline at end of file
