@@ -1,12 +1,11 @@
 import pygame
 import util
 from const import *
-import box, label
 
 from cellulose import *
 
 
-class SelectBox(box.VBox):
+class SelectBox(util.widgets.VBox):
     """
     SelectBox([multiple, [expand]]) -> SelectBox widget
     ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -26,7 +25,7 @@ class SelectBox(box.VBox):
     multiple = util.ReplaceableCellDescriptor()
 
     def __init__(self, multiple=False, **params):
-        box.VBox.__init__(self, scrollable=True, **params)
+        util.widgets.VBox.__init__(self, **params)
         self.selected = CellSet()
         self.options = CellDict()
         self.multiple = multiple
@@ -40,12 +39,12 @@ class SelectBox(box.VBox):
 
     def get_label(self, v):
         if hasattr(v, "value"):
-            l = label.Label(v.value, parent=self)
+            l = util.widgets.Label(v.value, parent=self, container=self)
             l._cells["value"] = ComputedCell(lambda:str(v.value))
         if type(v) == int:
             v = str(v)
         if type(v) == str:
-            l = label.Label(v, parent=self)
+            l = util.widgets.Label(v, parent=self)
         return l
 
     def add(self, label, value):
@@ -64,8 +63,7 @@ class SelectBox(box.VBox):
         """
         label = self.get_label(label)
         label._cells["disabled"] = self._cells["disabled"]
-        label.parent = self
-        box.VBox.add(self, label)
+        util.widgets.VBox.add(self, label)
         self.options[label] = value
         self.send(CHANGE)
 
@@ -102,10 +100,10 @@ class SelectBox(box.VBox):
         if type(option) == str:
             for k,v in self.options.items():
                 if v == option:
-                    box.VBox.remove(self, self.options[k])
+                    util.widgets.VBox.remove(self, self.options[k])
                     del self.options[k]
         else:
-            box.VBox.remove(self, option)
+            util.widgets.VBox.remove(self, option)
             del self.options[option]
         self.send(CHANGE)
 
