@@ -2,13 +2,12 @@ import pygame
 from pygame.locals import *
 import util
 from const import *
-import widget
 
 from cellulose import *
 from cellulose.restrictions import StringRestriction
 
 
-class TextBlock(widget.Widget):
+class TextBlock(util.widgets.Widget):
     """
     TextBlock(value) -> TextBlock widget
     ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -18,7 +17,7 @@ class TextBlock(widget.Widget):
     value = util.ReplaceableCellDescriptor(restriction=StringRestriction())
 
     def __init__(self, value, **params):
-        widget.Widget.__init__(self, **params)
+        util.widgets.Widget.__init__(self, **params)
 
         self.value = value
 
@@ -73,7 +72,7 @@ class TextBlock(widget.Widget):
         _,line_h = self.font.size("e")
         h = line_h*len(self.lines) + self.style_option["padding-bottom"]+\
                 self.style_option["padding-top"]
-        return widget.Widget.height.function(self, h)
+        return util.widgets.Widget.height.function(self, h)
     height = ComputedCellDescriptor(height)
 
     def draw_widget(self):
