@@ -4,7 +4,6 @@ import os, sys
 
 from cellulose import *
 
-
 screen = None
 screen_width = 0
 screen_height = 0
@@ -25,6 +24,17 @@ class ReplaceableCellDescriptor(InputCellDescriptor):
         else:
             self.get_cell(obj, value).set(value)
 
+widgets = None
+
+def gl_assign():
+    global widgets
+    import gl
+    widgets = gl
+
+def sdl_assign():
+    global widgets
+    import sdl
+    widgets = sdl
 
 def init(sw=640, sh=480, myscreen=None):
     global screen_width, screen_height, screen
@@ -37,6 +47,11 @@ def init(sw=640, sh=480, myscreen=None):
         screen_height = sh
         screen = pygame.display.set_mode((screen_width, screen_height))
 
+def glinit(sw=640, sh=480):
+    global screen_width, screen_height
+    screen_width = sw
+    screen_height = sh
+
 
 update_rects = []
 
@@ -60,6 +75,10 @@ def update_display():
     update_rects = []
 
 
+def get_ticks():
+    return pygame.time.get_ticks()
+
+
 imagestore = {}
 
 def get_image(path, colorkey=-1, nocache=False):
